@@ -14,21 +14,23 @@ Q_DECLARE_METATYPE(Qt::TextElideMode)
 
 namespace
 {
-
-KSqueezedTextLabel* createLabel(const QString &text = QStringLiteral("Squeeze me"))
+KSqueezedTextLabel *createLabel(const QString &text = QStringLiteral("Squeeze me"))
 {
-    KSqueezedTextLabel *label = new KSqueezedTextLabel(text, nullptr);
+    KSqueezedTextLabel *label = new KSqueezedTextLabel(QStringLiteral(""), nullptr);
     label->setSizePolicy(QSizePolicy::Preferred, QSizePolicy::Preferred);
+    // workaround for a QLabel bug, where the sizing for an empty label
+    // is off, if it was initialized to an empty text.
+    label->setText(QStringLiteral("x"));
+    label->setText(text);
     label->show();
     return label;
 }
 
-void squeezeLabel(KSqueezedTextLabel *label, const int pixels = 1)
+void squeezeLabel(KSqueezedTextLabel *label, const int pixels = 10)
 {
     label->resize(label->size().width() - pixels, label->size().height());
 }
 
-
 } // namespace
 
 void KSqueezedTextLabelAutotest::testEmptyText()
@@ -45,17 +47,19 @@ void KSqueezedTextLabelAutotest::testEmptyText()
 void KSqueezedTextLabelAutotest::testElisionOnResize_data()
 {
     QTest::addColumn<QString>("text");
+    QTest::addColumn<int>("squeezePixels");
 
-    QTest::newRow("whitespace text") << "             ";
-    QTest::newRow("normal text") << "Squeeze me";
-    QTest::newRow("rich text") << "<h1>Squeeze me!</h1>";
-//     QTest::newRow("multiline text") << "Squeeze me,\nand\nme too.";
-//     QTest::newRow("multiline rich text") << "<i>Squeeze</i> me,\n<b>and\nme</b> too.";
+    QTest::newRow("whitespace text") << "             " << 10;
+    QTest::newRow("normal text") << "Squeeze me" << 10;
+    QTest::newRow("rich text") << "<h1>Squeeze me!</h1>" << 80;
+    // QTest::newRow("multiline text") << "Squeeze me,\nand\nme too.";
+    // QTest::newRow("multiline rich text") << "<i>Squeeze</i> me,\n<b>and\nme</b> too.";
 }
 
 void KSqueezedTextLabelAutotest::testElisionOnResize()
 {
     QFETCH(QString, text);
+    QFETCH(int, squeezePixels);
 
     const QScopedPointer<KSqueezedTextLabel> label(createLabel(text));
 
@@ -64,14 +68,14 @@ void KSqueezedTextLabelAutotest::testElisionOnResize()
     QVERIFY(label->toolTip().isEmpty());
     QVERIFY(!label->isSqueezed());
 
-    squeezeLabel(label.data());
+    squeezeLabel(label.data(), squeezePixels);
 
     QVERIFY(label->text() != text);
     QVERIFY(label->fullText() == text);
     QVERIFY(label->toolTip() == text);
     QVERIFY(label->isSqueezed());
 
-    squeezeLabel(label.data(), -1);
+    squeezeLabel(label.data(), -squeezePixels);
 
     QVERIFY(label->text() == text);
     QVERIFY(label->fullText() == text);
@@ -98,7 +102,9 @@ void KSqueezedTextLabelAutotest::testElideMode_data()
     QTest::addColumn<QChar>("postfix");
 
     const QChar ellipsisChar(0x2026);
-    const QChar a(QLatin1Char('a')), b(QLatin1Char('b')), c(QLatin1Char('c'));
+    const QChar a(QLatin1Char('a'));
+    const QChar b(QLatin1Char('b'));
+    const QChar c(QLatin1Char('c'));
 
     QTest::newRow("ElideLeft") << Qt::ElideLeft << ellipsisChar << b << c;
     QTest::newRow("ElideRight") << Qt::ElideRight << a << b << ellipsisChar;
@@ -121,7 +127,7 @@ void KSqueezedTextLabelAutotest::testElideMode()
 
     QVERIFY(label->isSqueezed() || mode == Qt::ElideNone);
     QVERIFY(label->text().startsWith(prefix));
-    QVERIFY(0 < infixPos && infixPos < label->text().length()-1);
+    QVERIFY(0 < infixPos && infixPos < label->text().length() - 1);
     QVERIFY(label->text().endsWith(postfix));
 }
 
@@ -142,13 +148,12 @@ void KSqueezedTextLabelAutotest::testSizeHints()
     QCOMPARE(label->sizeHint().width(), 0);
 
     const QString text = QStringLiteral("Squeeze me");
-    const int labelWidth = label->fontMetrics().boundingRect(text).width();  // no chrome set
     label->setText(text);
+    const int labelWidth = label->sizeHint().width();
 
     QVERIFY(label->isSqueezed());
     QCOMPARE(label->size().width(), 0);
     QCOMPARE(label->minimumSizeHint().width(), -1);
-    QCOMPARE(label->sizeHint().width(), labelWidth);
 
     label->adjustSize();
 
@@ -222,7 +227,6 @@ void KSqueezedTextLabelAutotest::testChrome()
 
 QTEST_MAIN(KSqueezedTextLabelAutotest)
 
-
 // TODO
 // currently untested, may need clarification/definition of correct behaviour:
 // - multiline text
