@@ -1,19 +1,8 @@
-/* This file is part of the KDE libraries
-    Copyright (C) 2006 Olivier Goffart <ogoffart at kde.org>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2006 Olivier Goffart <ogoffart at kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License version 2 as published by the Free Software Foundation.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-only
 */
 
 #ifndef KASSISTANTDIALOG_H
@@ -23,6 +12,8 @@
 
 #include <kwidgetsaddons_export.h>
 
+class KAssistantDialogPrivate;
+
 /**
  * @class KAssistantDialog kassistantdialog.h KAssistantDialog
  *
@@ -54,8 +45,8 @@ public:
      * @flags the window flags to give to the assistant dialog. The
      * default of zero is usually what you want.
      */
-    explicit KAssistantDialog(QWidget *parent = nullptr, Qt::WindowFlags flags = nullptr);
-    virtual ~KAssistantDialog();
+    explicit KAssistantDialog(QWidget *parent = nullptr, Qt::WindowFlags flags = Qt::WindowFlags());
+    ~KAssistantDialog() override;
 
     /**
      * Specify if the content of the page is valid, and if the next button may be enabled on this page.
@@ -70,8 +61,8 @@ public:
 
     /**
      * return if a page is valid
-     * @see setValid
      * @param page the page to check the validity of
+     * @see setValid()
      */
     bool isValid(KPageWidgetItem *page) const;
 
@@ -101,17 +92,17 @@ public:
     /**
      * @returns the next button
      */
-    QPushButton* nextButton() const;
+    QPushButton *nextButton() const;
 
     /**
      * @returns the finish button
      */
-    QPushButton* backButton() const;
+    QPushButton *backButton() const;
 
     /**
      * @returns the finish button
      */
-    QPushButton* finishButton() const;
+    QPushButton *finishButton() const;
 
 public Q_SLOTS:
     /**
@@ -140,15 +131,16 @@ protected:
      *
      * Calls the KPageDialog(KPageWidget *widget, QWidget *parent, Qt::WindowFlags flags) constructor
      */
-    explicit KAssistantDialog(KPageWidget *widget, QWidget *parent = nullptr, Qt::WindowFlags flags = nullptr);
+    explicit KAssistantDialog(KPageWidget *widget, QWidget *parent = nullptr, Qt::WindowFlags flags = Qt::WindowFlags());
 
-    void showEvent(QShowEvent *event) Q_DECL_OVERRIDE;
+    void showEvent(QShowEvent *event) override;
 
 private:
-    class Private;
-    Private *const d;
-
-    Q_PRIVATE_SLOT(d, void _k_slotUpdateButtons())
+    Q_DECLARE_PRIVATE(KAssistantDialog)
+#if KWIDGETSADDONS_BUILD_DEPRECATED_SINCE(5, 79)
+    // Unused, kept for ABI compatibility
+    const void *__kwidgetsaddons_d_do_not_use;
+#endif
 
     Q_DISABLE_COPY(KAssistantDialog)
 };
