@@ -1,27 +1,13 @@
 /*
-    Copyright 2011 John Layt <john@layt.net>
+    SPDX-FileCopyrightText: 2011 John Layt <john@layt.net>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "kdatetimeedit.h"
 
-
-#include "kdatepicker.h"
 #include "kdatecombobox.h"
+#include "kdatepicker.h"
 #include "kmessagebox.h"
 
 #include "ui_kdatetimeedit.h"
@@ -29,7 +15,7 @@
 class KDateTimeEditPrivate
 {
 public:
-    KDateTimeEditPrivate(KDateTimeEdit *q);
+    KDateTimeEditPrivate(KDateTimeEdit *qq);
     virtual ~KDateTimeEditPrivate();
 
     QDateTime defaultMinDateTime();
@@ -45,7 +31,7 @@ public:
 
     void warnDateTime();
 
-//private Q_SLOTS:
+    // private Q_SLOTS:
     void selectCalendar(int index);
     void enterCalendar(const QLocale &calendarLocale);
     void selectTimeZone(int index);
@@ -66,12 +52,11 @@ public:
     Ui::KDateTimeEdit ui;
 };
 
-KDateTimeEditPrivate::KDateTimeEditPrivate(KDateTimeEdit *q)
-    : q(q)
+KDateTimeEditPrivate::KDateTimeEditPrivate(KDateTimeEdit *qq)
+    : q(qq)
 {
-    m_options = KDateTimeEdit::ShowDate | KDateTimeEdit::EditDate | KDateTimeEdit::SelectDate |
-                KDateTimeEdit::ShowTime | KDateTimeEdit::EditTime | KDateTimeEdit::SelectTime |
-                KDateTimeEdit::DatePicker | KDateTimeEdit::DateKeywords;
+    m_options = KDateTimeEdit::ShowDate | KDateTimeEdit::EditDate | KDateTimeEdit::SelectDate | KDateTimeEdit::ShowTime | KDateTimeEdit::EditTime
+        | KDateTimeEdit::SelectTime | KDateTimeEdit::DatePicker | KDateTimeEdit::DateKeywords;
     m_dateTime = QDateTime::currentDateTime();
     m_dateTime.setTime(QTime(0, 0, 0));
     m_calendarLocales << q->locale();
@@ -89,14 +74,14 @@ KDateTimeEditPrivate::~KDateTimeEditPrivate()
 QDateTime KDateTimeEditPrivate::defaultMinDateTime()
 {
     // TODO: Find a way to get it from QLocale
-    //return KDateTime(calendar()->earliestValidDate(), QTime(0, 0, 0, 0));
+    // return KDateTime(calendar()->earliestValidDate(), QTime(0, 0, 0, 0));
     return QDateTime();
 }
 
 QDateTime KDateTimeEditPrivate::defaultMaxDateTime()
 {
     // TODO: Find a way to get it from QLocale
-    //return KDateTime(calendar()->latestValidDate(), QTime(23, 59, 59, 999));
+    // return KDateTime(calendar()->latestValidDate(), QTime(23, 59, 59, 999));
     return QDateTime();
 }
 
@@ -151,7 +136,7 @@ void KDateTimeEditPrivate::initCalendarWidget()
 {
     ui.m_calendarCombo->blockSignals(true);
     ui.m_calendarCombo->clear();
-    for (const QLocale &calendarLocale : qAsConst(m_calendarLocales)) {
+    for (const QLocale &calendarLocale : std::as_const(m_calendarLocales)) {
         ui.m_calendarCombo->addItem(calendarLocale.name(), calendarLocale);
     }
     ui.m_calendarCombo->setCurrentIndex(ui.m_calendarCombo->findData(q->locale()));
@@ -176,16 +161,16 @@ void KDateTimeEditPrivate::selectCalendar(int index)
 void KDateTimeEditPrivate::enterCalendar(const QLocale &calendarLocale)
 {
     q->setLocale(calendarLocale);
-    emit q->calendarEntered(q->locale());
+    Q_EMIT q->calendarEntered(q->locale());
 }
 
 void KDateTimeEditPrivate::initTimeZoneWidget()
 {
     ui.m_timeZoneCombo->blockSignals(true);
     ui.m_timeZoneCombo->clear();
-    ui.m_timeZoneCombo->addItem(KDateTimeEdit::tr("UTC", "UTC time zone"), QByteArray("UTC"));
-    ui.m_timeZoneCombo->addItem(KDateTimeEdit::tr("Floating", "No specific time zone"), QByteArray());
-    for (const QTimeZone &zone : qAsConst(m_zones)) {
+    ui.m_timeZoneCombo->addItem(KDateTimeEdit::tr("UTC", "@item:inlistbox UTC time zone"), QByteArray("UTC"));
+    ui.m_timeZoneCombo->addItem(KDateTimeEdit::tr("Floating", "@item:inlistbox No specific time zone"), QByteArray());
+    for (const QTimeZone &zone : std::as_const(m_zones)) {
         ui.m_timeZoneCombo->addItem(QString::fromUtf8(zone.id()), zone.id());
     }
     ui.m_timeZoneCombo->setVisible((m_options & KDateTimeEdit::ShowTimeZone) == KDateTimeEdit::ShowTimeZone);
@@ -208,32 +193,31 @@ void KDateTimeEditPrivate::selectTimeZone(int index)
 void KDateTimeEditPrivate::enterTimeZone(const QByteArray &zoneId)
 {
     q->setTimeZone(QTimeZone(zoneId));
-    emit q->dateTimeEntered(m_dateTime);
-    emit q->timeZoneEntered(m_dateTime.timeZone());
+    Q_EMIT q->dateTimeEntered(m_dateTime);
+    Q_EMIT q->timeZoneEntered(m_dateTime.timeZone());
 }
 
 void KDateTimeEditPrivate::warnDateTime()
 {
-    if (!q->isValid() &&
-            (m_options & KDateTimeEdit::WarnOnInvalid) == KDateTimeEdit::WarnOnInvalid) {
+    if (!q->isValid() && (m_options & KDateTimeEdit::WarnOnInvalid) == KDateTimeEdit::WarnOnInvalid) {
         QString warnMsg;
         if (!m_dateTime.isValid()) {
-            //TODO Add missing string
-            //warnMsg = tr("The date or time you entered is invalid");
+            // TODO Add missing string
+            // warnMsg = tr("The date or time you entered is invalid");
         } else if (m_minDateTime.isValid() && m_dateTime < m_minDateTime) {
             if (m_minWarnMsg.isEmpty()) {
-                //TODO Add datetime to string
-                //warnMsg = q->tr("Date and time cannot be earlier than %1", "@info").arg(formatDate(m_minDate));
+                // TODO Add datetime to string
+                // warnMsg = q->tr("Date and time cannot be earlier than %1", "@info").arg(formatDate(m_minDate));
                 warnMsg = KDateTimeEdit::tr("The entered date and time is before the minimum allowed date and time.", "@info");
             } else {
                 warnMsg = m_minWarnMsg;
-                //TODO localize properly
+                // TODO localize properly
                 warnMsg.replace(QLatin1String("%1"), q->locale().toString(m_minDateTime));
             }
         } else if (m_maxDateTime.isValid() && m_dateTime > m_maxDateTime) {
             if (m_maxWarnMsg.isEmpty()) {
-                //TODO Add datetime to string
-                //warnMsg = q->tr("Date cannot be later than %1", "@info").arg(formatDate(m_maxDate));
+                // TODO Add datetime to string
+                // warnMsg = q->tr("Date cannot be later than %1", "@info").arg(formatDate(m_maxDate));
                 warnMsg = KDateTimeEdit::tr("The entered date and time is after the maximum allowed date and time.", "@info");
             } else {
                 warnMsg = m_maxWarnMsg;
@@ -245,12 +229,12 @@ void KDateTimeEditPrivate::warnDateTime()
 }
 
 KDateTimeEdit::KDateTimeEdit(QWidget *parent)
-    : QWidget(parent),
-      d(new KDateTimeEditPrivate(this))
+    : QWidget(parent)
+    , d(new KDateTimeEditPrivate(this))
 {
     d->ui.setupUi(this);
-    //Need to do the min/max defaults here and not in private init as need to wait for ui to init
-    //the KDateComboBox which holds the calendar object.  Revisit this???
+    // Need to do the min/max defaults here and not in private init as need to wait for ui to init
+    // the KDateComboBox which holds the calendar object.  Revisit this???
     d->m_minDateTime = d->defaultMinDateTime();
     d->m_maxDateTime = d->defaultMaxDateTime();
     d->ui.m_calendarCombo->installEventFilter(this);
@@ -259,20 +243,17 @@ KDateTimeEdit::KDateTimeEdit(QWidget *parent)
     d->ui.m_timeZoneCombo->installEventFilter(this);
     d->initWidgets();
 
-    connect(d->ui.m_dateCombo, &KDateComboBox::dateChanged,
-            this,                  &KDateTimeEdit::setDate);
-    connect(d->ui.m_timeCombo, &KTimeComboBox::timeChanged,
-            this,                  &KDateTimeEdit::setTime);
-    connect(d->ui.m_calendarCombo, SIGNAL(activated(int)),
-            this,                      SLOT(selectCalendar(int)));
-    connect(d->ui.m_timeZoneCombo, SIGNAL(activated(int)),
-            this,                      SLOT(selectTimeZone(int)));
+    connect(d->ui.m_dateCombo, &KDateComboBox::dateChanged, this, &KDateTimeEdit::setDate);
+    connect(d->ui.m_timeCombo, &KTimeComboBox::timeChanged, this, &KDateTimeEdit::setTime);
+    connect(d->ui.m_calendarCombo, qOverload<int>(&QComboBox::activated), this, [this](int index) {
+        d->selectCalendar(index);
+    });
+    connect(d->ui.m_timeZoneCombo, qOverload<int>(&QComboBox::activated), this, [this](int index) {
+        d->selectTimeZone(index);
+    });
 }
 
-KDateTimeEdit::~KDateTimeEdit()
-{
-    delete d;
-}
+KDateTimeEdit::~KDateTimeEdit() = default;
 
 QDateTime KDateTimeEdit::dateTime() const
 {
@@ -296,9 +277,9 @@ QTimeZone KDateTimeEdit::timeZone() const
 
 bool KDateTimeEdit::isValid() const
 {
-    return d->m_dateTime.isValid() &&
-           (!d->m_minDateTime.isValid() || d->m_dateTime >= d->m_minDateTime) &&
-           (!d->m_maxDateTime.isValid() || d->m_dateTime <= d->m_maxDateTime);
+    return d->m_dateTime.isValid() //
+        && (!d->m_minDateTime.isValid() || d->m_dateTime >= d->m_minDateTime) //
+        && (!d->m_maxDateTime.isValid() || d->m_dateTime <= d->m_maxDateTime);
 }
 
 bool KDateTimeEdit::isNull() const
@@ -343,9 +324,9 @@ void KDateTimeEdit::setDateTime(const QDateTime &dateTime)
 {
     if (dateTime != d->m_dateTime) {
         assignDateTime(dateTime);
-        emit dateTimeChanged(d->m_dateTime);
-        emit dateChanged(d->m_dateTime.date());
-        emit timeChanged(d->m_dateTime.time());
+        Q_EMIT dateTimeChanged(d->m_dateTime);
+        Q_EMIT dateChanged(d->m_dateTime.date());
+        Q_EMIT timeChanged(d->m_dateTime.time());
     }
 }
 
@@ -360,8 +341,8 @@ void KDateTimeEdit::setDate(const QDate &date)
 {
     if (date != d->m_dateTime.date()) {
         assignDate(date);
-        emit dateTimeChanged(d->m_dateTime);
-        emit dateChanged(d->m_dateTime.date());
+        Q_EMIT dateTimeChanged(d->m_dateTime);
+        Q_EMIT dateChanged(d->m_dateTime.date());
     }
 }
 
@@ -375,8 +356,8 @@ void KDateTimeEdit::setTime(const QTime &time)
 {
     if (time != d->m_dateTime.time()) {
         assignTime(time);
-        emit dateTimeChanged(d->m_dateTime);
-        emit timeChanged(d->m_dateTime.time());
+        Q_EMIT dateTimeChanged(d->m_dateTime);
+        Q_EMIT timeChanged(d->m_dateTime.time());
     }
 }
 
@@ -393,8 +374,8 @@ void KDateTimeEdit::setTimeZone(const QTimeZone &zone)
     }
 
     assignTimeZone(zone);
-    emit dateTimeChanged(d->m_dateTime);
-    emit timeZoneChanged(d->m_dateTime.timeZone());
+    Q_EMIT dateTimeChanged(d->m_dateTime);
+    Q_EMIT timeZoneChanged(d->m_dateTime.timeZone());
 }
 
 void KDateTimeEdit::assignTimeZone(const QTimeZone &zone)
@@ -433,20 +414,13 @@ void KDateTimeEdit::resetMaximumDateTime()
     d->m_maxDateTime = d->defaultMaxDateTime();
 }
 
-void KDateTimeEdit::setDateTimeRange(const QDateTime &minDateTime,
-                                     const QDateTime &maxDateTime,
-                                     const QString &minErrorMsg,
-                                     const QString &maxErrorMsg)
+void KDateTimeEdit::setDateTimeRange(const QDateTime &minDateTime, const QDateTime &maxDateTime, const QString &minErrorMsg, const QString &maxErrorMsg)
 {
-    if (minDateTime.isValid() &&
-            maxDateTime.isValid() &&
-            minDateTime <= maxDateTime) {
-
+    if (minDateTime.isValid() && maxDateTime.isValid() && minDateTime <= maxDateTime) {
         d->m_minDateTime = minDateTime;
         d->m_minWarnMsg = minErrorMsg;
         d->m_maxDateTime = maxDateTime;
         d->m_maxWarnMsg = maxErrorMsg;
-
     }
 }
 
@@ -508,9 +482,7 @@ int KDateTimeEdit::timeListInterval() const
     return d->ui.m_timeCombo->timeListInterval();
 }
 
-void KDateTimeEdit::setTimeList(QList<QTime> timeList,
-                                const QString &minWarnMsg,
-                                const QString &maxWarnMsg)
+void KDateTimeEdit::setTimeList(QList<QTime> timeList, const QString &minWarnMsg, const QString &maxWarnMsg)
 {
     d->ui.m_timeCombo->setTimeList(timeList, minWarnMsg, maxWarnMsg);
 }
