@@ -10,13 +10,12 @@
 
 #include <QDialogButtonBox>
 #include <QPointer>
-#include <QPushButton>
 #include <QVBoxLayout>
 
 class KFontChooserDialogPrivate
 {
 public:
-    KFontChooser *chooser = nullptr;
+    KFontChooser *m_fontChooser = nullptr;
 };
 
 KFontChooserDialog::KFontChooserDialog(const KFontChooser::DisplayFlags &flags, QWidget *parent)
@@ -24,33 +23,31 @@ KFontChooserDialog::KFontChooserDialog(const KFontChooser::DisplayFlags &flags,
     , d(new KFontChooserDialogPrivate)
 {
     setWindowTitle(tr("Select Font", "@title:window"));
-    d->chooser = new KFontChooser(this, flags, QStringList(), 8 /*visibleListSize*/, nullptr /*sizeIsRelativeState*/);
-    d->chooser->setObjectName(QStringLiteral("fontChooser"));
+    d->m_fontChooser = new KFontChooser(flags, this);
+    d->m_fontChooser->setMinVisibleItems(8);
+    d->m_fontChooser->setObjectName(QStringLiteral("fontChooser"));
 
-    connect(d->chooser, &KFontChooser::fontSelected, this, &KFontChooserDialog::fontSelected);
+    connect(d->m_fontChooser, &KFontChooser::fontSelected, this, &KFontChooserDialog::fontSelected);
 
     QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
     QVBoxLayout *mainLayout = new QVBoxLayout(this);
-    mainLayout->addWidget(d->chooser);
+    mainLayout->addWidget(d->m_fontChooser);
     mainLayout->addWidget(buttonBox);
 
     connect(buttonBox, &QDialogButtonBox::accepted, this, &QDialog::accept);
     connect(buttonBox, &QDialogButtonBox::rejected, this, &QDialog::reject);
 }
 
-KFontChooserDialog::~KFontChooserDialog()
-{
-    delete d;
-}
+KFontChooserDialog::~KFontChooserDialog() = default;
 
 void KFontChooserDialog::setFont(const QFont &font, bool onlyFixed)
 {
-    d->chooser->setFont(font, onlyFixed);
+    d->m_fontChooser->setFont(font, onlyFixed);
 }
 
 QFont KFontChooserDialog::font() const
 {
-    return d->chooser->font();
+    return d->m_fontChooser->font();
 }
 
 // If the styleName property is set for a QFont, using setBold(true) would
@@ -81,8 +78,8 @@ int KFontChooserDialog::getFontDiff(QFont &theFont, KFontChooser::FontDiffFlags
 
     const int result = dialog->exec();
     if (result == Accepted) {
-        theFont = dialog->d->chooser->font();
-        diffFlags = dialog->d->chooser->fontDiffFlags();
+        theFont = dialog->d->m_fontChooser->font();
+        diffFlags = dialog->d->m_fontChooser->fontDiffFlags();
         stripRegularStyleName(theFont);
     }
     delete dialog;
@@ -98,7 +95,7 @@ int KFontChooserDialog::getFont(QFont &theFont, const KFontChooser::DisplayFlags
 
     const int result = dialog->exec();
     if (result == Accepted) {
-        theFont = dialog->d->chooser->font();
+        theFont = dialog->d->m_fontChooser->font();
         stripRegularStyleName(theFont);
     }
     delete dialog;
