@@ -31,8 +31,8 @@ public:
 class KGradientSelectorPrivate
 {
 public:
-    KGradientSelectorPrivate(KGradientSelector *q)
-        : q(q)
+    KGradientSelectorPrivate(KGradientSelector *qq)
+        : q(qq)
     {
     }
 
@@ -166,10 +166,11 @@ void KSelector::moveArrow(const QPoint &pos)
     int w = style()->pixelMetric(QStyle::PM_DefaultFrameWidth);
     int iw = (w < ARROWSIZE) ? ARROWSIZE : w;
 
-    if (orientation() == Qt::Vertical)
+    if (orientation() == Qt::Vertical) {
         val = (maximum() - minimum()) * (height() - pos.y() - iw) / (height() - iw * 2) + minimum();
-    else
+    } else {
         val = (maximum() - minimum()) * (pos.x() - iw) / (width() - iw * 2) + minimum();
+    }
 
     setValue(val);
     update();
