@@ -1,27 +1,16 @@
-/* This file is part of the KDE libraries
-    Copyright (C) 1999 Reginald Stadlbauer <reggie@kde.org>
-              (C) 1999 Simon Hausmann <hausmann@kde.org>
-              (C) 2000 Nicolas Hadacek <haadcek@kde.org>
-              (C) 2000 Kurt Granroth <granroth@kde.org>
-              (C) 2000 Michael Koch <koch@kde.org>
-              (C) 2001 Holger Freyther <freyther@kde.org>
-              (C) 2002 Ellis Whitehead <ellis@kde.org>
-              (C) 2003 Andras Mantia <amantia@kde.org>
-              (C) 2005-2006 Hamish Rodda <rodda@kde.org>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 1999 Reginald Stadlbauer <reggie@kde.org>
+    SPDX-FileCopyrightText: 1999 Simon Hausmann <hausmann@kde.org>
+    SPDX-FileCopyrightText: 2000 Nicolas Hadacek <haadcek@kde.org>
+    SPDX-FileCopyrightText: 2000 Kurt Granroth <granroth@kde.org>
+    SPDX-FileCopyrightText: 2000 Michael Koch <koch@kde.org>
+    SPDX-FileCopyrightText: 2001 Holger Freyther <freyther@kde.org>
+    SPDX-FileCopyrightText: 2002 Ellis Whitehead <ellis@kde.org>
+    SPDX-FileCopyrightText: 2003 Andras Mantia <amantia@kde.org>
+    SPDX-FileCopyrightText: 2005-2006 Hamish Rodda <rodda@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License version 2 as published by the Free Software Foundation.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-only
 */
 
 #ifndef KTOGGLEFULLSCREENACTION_H
@@ -29,7 +18,13 @@
 
 #include <ktoggleaction.h>
 
+class QWidget;
+
+class KToggleFullScreenActionPrivate;
+
 /**
+ * @class KToggleFullScreenAction ktogglefullscreenaction.h KToggleFullScreenAction
+ *
  * An action for switching between to/from full screen mode. Note that
  * QWidget::isFullScreen() may reflect the new or the old state
  * depending on how the action was triggered (by the application or
@@ -41,7 +36,7 @@
  * do not call directly the slot connected to the toggled() signal. The slot
  * still needs to explicitly set the window state though.
  *
- * Note: Do NOT use QWidget::showFullScreen() or QWidget::showNormal().
+ * @note Do NOT use QWidget::showFullScreen() or QWidget::showNormal().
  * They have several side-effects besides just switching the fullscreen
  * state (for example, showNormal() resets all window states, not just
  * fullscreen). Use the KToggleFullScreenAction::setFullScreen() helper function.
@@ -69,7 +64,7 @@ public:
     /**
      * Destroys the toggle fullscreen action.
      */
-    virtual ~KToggleFullScreenAction();
+    ~KToggleFullScreenAction() override;
 
     /**
      * Sets the window that will be related to this action.
@@ -84,14 +79,17 @@ public:
     static void setFullScreen(QWidget *window, bool set);
 
 protected:
-    bool eventFilter(QObject *object, QEvent *event) Q_DECL_OVERRIDE;
+    bool eventFilter(QObject *object, QEvent *event) override;
 
 protected Q_SLOTS:
-    void slotToggled(bool checked) Q_DECL_OVERRIDE;
+    void slotToggled(bool checked) override;
 
 private:
-    class Private;
-    Private *const d;
+    Q_DECLARE_PRIVATE_D(KToggleAction::d, KToggleFullScreenAction)
+#if KWIDGETSADDONS_BUILD_DEPRECATED_SINCE(5, 79)
+    // Unused, kept for ABI compatibility
+    const void *__kwidgetsaddons_d_do_not_use;
+#endif
 };
 
 #endif
